@@ -23,20 +23,20 @@ lazy_static! {
 
 pub struct LoggerSender {
     pub filter: Box<dyn Filter>,
-    pub inner: Sender<FastLogRecord>,
+    pub inner: crossbeam::channel::Sender<FastLogRecord>,
 }
 
 impl LoggerSender {
-    pub fn new( filter: Box<dyn Filter>) -> (Self, Receiver<FastLogRecord>) {
-        let (s, r) = may::sync::mpsc::channel();
+    pub fn new(filter: Box<dyn Filter>) -> (Self, crossbeam::channel::Receiver<FastLogRecord>) {
+        let (s, r) = crossbeam::channel::unbounded();
         (Self { inner: s, filter }, r)
     }
-    pub fn send(&self, data: FastLogRecord) -> Result<(), SendError<FastLogRecord>> {
+    pub fn send(&self, data: FastLogRecord) -> Result<(), crossbeam::channel::SendError<FastLogRecord>> {
         self.inner.send(data)
     }
 }
 
-fn set_log( level: log::Level, filter: Box<dyn Filter>) -> Receiver<FastLogRecord> {
+fn set_log(level: log::Level, filter: Box<dyn Filter>) -> crossbeam::channel::Receiver<FastLogRecord> {
     LOGGER.set_level(level);
     let mut w = LOG_SENDER.write();
     let (log, recv) = LoggerSender::new(filter);
@@ -74,6 +74,11 @@ impl log::Log for Logger {
         //send
         if let Some(sender) = LOG_SENDER.read().as_ref() {
             if !sender.filter.filter(record) {
+                if let Some(v) = record.module_path() {
+                    if v == "may::io::sys::select" {
+                        return;
+                    }
+                }
                 let fast_log_record = FastLogRecord {
                     command: Command::CommandRecord,
                     level: record.level(),
@@ -169,7 +174,7 @@ pub fn init_custom_log(
     }
     let wait_group = FastLogWaitGroup::new();
     let main_recv = set_log(level, filter);
-    let (back_sender, back_recv) =  may::sync::mpsc::channel();
+    let (back_sender, back_recv) = may::sync::mpsc::channel();
     //main recv data
     let wait_group_main = wait_group.clone();
     go!(move ||{
@@ -188,7 +193,7 @@ pub fn init_custom_log(
     });
     let wait_group_back = wait_group.clone();
     //back recv data
-    std::thread::spawn(move || {
+    go!(move || {
         loop {
             //recv
             let data = back_recv.recv();
@@ -197,7 +202,7 @@ pub fn init_custom_log(
                     drop(wait_group_back);
                     break;
                 }
-                format.do_format(&mut data);
+                data.formated = format.do_format(&mut data);
                 for x in &appenders {
                     x.do_log(&mut data);
                 }
