@@ -11,12 +11,9 @@ pub struct FileAppender {
 impl FileAppender {
     pub fn new(log_file_path: &str) -> FileAppender {
         let log_file_path = log_file_path.replace("\\", "/");
-        match log_file_path.rfind("/") {
-            None => {}
-            Some(right) => {
-                let path = &log_file_path[0..right];
-                std::fs::create_dir_all(path);
-            }
+        if let Some(right) = log_file_path.rfind("/") {
+            let path = &log_file_path[0..right];
+            std::fs::create_dir_all(path);
         }
         Self {
             file: RefCell::new(
@@ -31,13 +28,11 @@ impl FileAppender {
 }
 
 impl LogAppender for FileAppender {
-    fn do_log(&self, records: &mut [FastLogRecord]) {
+    fn do_log(&self, record: &mut FastLogRecord) {
         let mut log_file = self.file.borrow_mut();
         let mut buf = vec![];
-        for x in records {
-            for x in x.formated.bytes() {
-                buf.push(x);
-            }
+        for x in record.formated.bytes() {
+            buf.push(x);
         }
         log_file.write_all(buf.as_slice());
         log_file.flush();
